<?php

/*
=====================================================
 Extension: Show Entry Views
-----------------------------------------------------
 Author: Yvonne
 Version: 1.1.0
=====================================================
 File: ext.show_entry_views.php
-----------------------------------------------------
 Purpose: This extension will show you the entry view counters
 on the Edit page in the ExpressionEngine control panel.
=====================================================
*/

if ( ! defined('EXT'))
{
    exit('Invalid file request');
}


class Show_entry_views
{
	var $settings 				= array();
	
	var $name 					= 'Show Entry Views';
	var $version 				= '1.1.0';
	var $description 			= 'Shows entry views for each entry on the Edit Page.';
	var $settings_exist 		= 'y';
	var $docs_url 				= 'http://www.ennovy.org/weblog/comments/show-entry-views-extension/';
	
	// -------------------------------
	//   Constructor - Extensions use this for settings
	// -------------------------------
	
	function Show_entry_views($settings='')
	{
		global $LANG;
		$LANG->fetch_language_file('show_entry_views');
		$this->settings = $settings;
		$this->name = $LANG->line('show_entry_views_name');
		$this->description = $LANG->line('show_entry_views_description');
	}
	// END
	
	// -------------------------------
	// 	Add more fields to the search query
	// -------------------------------

	function entry_view_search_fields()
	{
		global $EXT;
		
		$views = in_array('all', $this->settings['which_views']) || in_array('total', $this->settings['which_views']) ? array('one','two','three','four') : $this->settings['which_views'];
		$str = $EXT->last_call!=false ? $EXT->last_call : '';
		
		foreach($views as $view)
		{
			$str .= ', exp_weblog_titles.view_count_'.$view.' ';
		}
		
		return $str;
	}
	// END

	// -------------------------------
	// 	Add columns to the view entries page
	// -------------------------------

	function entry_view_tableheader($row)
	{
		global $DSP, $EXT, $LANG;
		
		$views = in_array('all', $this->settings['which_views']) ? array('one','two','three','four','total') : $this->settings['which_views'];
		$str = $EXT->last_call!=false ? $EXT->last_call : '';

		foreach($views as $view)
		{
			$str .= $DSP->table_qcell('tableHeadingAlt', $LANG->line($view));
		}
		
		return $str;
	}
	// END

	// -------------------------------
	// 	Add link
	// -------------------------------
	
	function entry_view_celldata($row)
	{
		global $DSP, $EXT, $LANG;
		
		$total = 0;
		if (in_array('total', $this->settings['which_views']) || in_array('all', $this->settings['which_views']))
		{
			$total = $row['view_count_one'] + $row['view_count_two'] + $row['view_count_three'] + $row['view_count_four'];
		}
		
		$views = in_array('all', $this->settings['which_views']) ? array('one','two','three','four','total') : $this->settings['which_views'];
		$str = $EXT->last_call!=false ? $EXT->last_call : '';
		
		foreach($views as $view)
		{
			$str .= $DSP->table_qcell('tableCellOne', ($view == 'total' ? $total : $row['view_count_'.$view]));
		}
		
		return $str;
	}
	// END
    
	// --------------------------------
	//  Activate Extension
	// --------------------------------
    
	function activate_extension()
	{
		global $DB, $PREFS;
    
		$default_settings = serialize(array('which_views' 	=> array('all')));
		   
		$DB->query($DB->insert_string('exp_extensions',
    								  array('extension_id'	=> '',
    										'class'			=> "Show_entry_views",
    										'method'		=> "entry_view_tableheader",
    										'hook'			=> "edit_entries_additional_tableheader",
    										'settings'		=> $default_settings,
    										'priority'		=> 2,
    										'version'		=> $this->version,
    										'enabled'		=> "y"
    										)
    								 )
    			   );	
		$DB->query($DB->insert_string('exp_extensions',
    								  array('extension_id'	=> '',
    										'class'			=> "Show_entry_views",
    										'method'		=> "entry_view_celldata",
    										'hook'			=> "edit_entries_additional_celldata",
    										'settings'		=> $default_settings,
    										'priority'		=> 2,
    										'version'		=> $this->version,
    										'enabled'		=> "y"
    										)
    								 )
    			   );
		$DB->query($DB->insert_string('exp_extensions',
    								  array('extension_id'	=> '',
    										'class'			=> "Show_entry_views",
    										'method'		=> "entry_view_search_fields",
    										'hook'			=> "edit_entries_search_fields",
    										'settings'		=> $default_settings,
    										'priority'		=> 2,
    										'version'		=> $this->version,
    										'enabled'		=> "y"
    										)
    								 )
    			   );    			   
	}
	// END

	// --------------------------------
	//  Update Extension
	// --------------------------------  
	
	function update_extension($current='')
	{
		global $DB;
			
		if ($current == '' OR $current == $this->version)
		{
			return FALSE;
		}
    	
		if ($current < '1.1.0')
		{
			// Update to next version 1.0.1
		}

		$DB->query("UPDATE exp_extensions 
    				SET version = '".$DB->escape_str($this->version)."' 
    				WHERE class = 'Show_entry_views'");
	}
	// END
    
    
	// --------------------------------
	//  Settings
	// --------------------------------  
	
	function settings()
	{
		global $LANG;
		
		$settings = array();
		
		$settings['which_views'] = array('ms', array('all'=> $LANG->line('all'), 'one' => $LANG->line('one'), 'two' => $LANG->line('two'), 'three' => $LANG->line('three'), 'four' => $LANG->line('four'), 'total' => $LANG->line('total')), 'all'); 
		
		// Complex:
		// [variable_name] => array(type, values, default)
		// variable_name => short name for setting and used as the key for language file
		// type:  t - textarea, r - radio buttons, s - select, ms - multiselect, f - function calls
		// values:  can be array (r, s, ms), string (t), function name (f)
		// default:  name of array member, string, nothing
		//
		// Simple:
		// [variable_name] => 'Butter'
		// Text input, with 'Butter' as the default.
		
		return $settings;
	}
	// END

}
// END Class

?>